function [ cleDrawDatOut ] = cleRotate(cleDrawDatIn,rotXYTheta)
%cleRotate    - Rotate cleDrawDat structure.
%
%   cleDrawDat = cleRotate(cleDrawDat, rotXYTheta)
%       rotXYTheta  - Nx3 array of [Xc Yc theta] rotate coordinates.

if (isstruct(cleDrawDatIn) & isnumeric(rotXYTheta) )
 if ( size(rotXYTheta,2)~=3 )
  rotXYTheta=rotXYTheta';
 end;

 if (size(rotXYTheta,2)~=3)
  error('CleWin:cleRotate:InputError', ...
        'Incorrect input parameter(s).');
 end;
else
  error('CleWin:cleRotate:InputError', ...
        'Incorrect input parameter(s).');
end;

cleDrawDatOut=cleEmpty();

clear i;
for r=1:size(rotXYTheta,1),
 x=rotXYTheta(r,1);
 y=rotXYTheta(r,2);
 rot_angle=rotXYTheta(r,3);

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.cleCircle),
  r=sqrt( (cleDrawDatIn.cleCircle{k}.x-x)^2 + (cleDrawDatIn.cleCircle{k}.y-y)^2);
  phi=angle((cleDrawDatIn.cleCircle{k}.x-x)+i*(cleDrawDatIn.cleCircle{k}.y-y));
 
  cleDrawDatOut.cleCircle{end+1}=cleDrawDatIn.cleCircle{k};
  cleDrawDatOut.cleCircle{end}.x=x+r*cos(rot_angle+phi);
  cleDrawDatOut.cleCircle{end}.y=y+r*sin(rot_angle+phi);
 end;
 %------------------------------------------------------------

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.cleBox),
  r=sqrt( (cleDrawDatIn.cleBox{k}.x-x)^2 + (cleDrawDatIn.cleBox{k}.y-y)^2);
  phi=angle((cleDrawDatIn.cleBox{k}.x-x)+i*(cleDrawDatIn.cleBox{k}.y-y));
 
  cleDrawDatOut.cleBox{end+1}=cleDrawDatIn.cleBox{k};
  cleDrawDatOut.cleBox{end}.x=x+r*cos((rot_angle+phi));
  cleDrawDatOut.cleBox{end}.y=y+r*sin((rot_angle+phi));
  cleDrawDatOut.cleBox{end}.angle=cleDrawDatIn.cleBox{k}.angle+rot_angle;
 end;
 %------------------------------------------------------------

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.clePolygon),
  nclePolygons=length(cleDrawDatOut.clePolygon)+1;
  cleDrawDatOut.clePolygon{nclePolygons}=cleDrawDatIn.clePolygon{k};
  cleDrawDatOut.clePolygon{nclePolygons}.points=[];

  for m=1:length(cleDrawDatIn.clePolygon{k}.points),
   r=sqrt( (cleDrawDatIn.clePolygon{k}.points(m,1)-x)^2 + (cleDrawDatIn.clePolygon{k}.points(m,2)-y)^2);
   phi=angle((cleDrawDatIn.clePolygon{k}.points(m,1)-x)+i*(cleDrawDatIn.clePolygon{k}.points(m,2)-y));
 
   cleDrawDatOut.clePolygon{nclePolygons}.points =[cleDrawDatOut.clePolygon{nclePolygons}.points ; ...
           [ x+r*cos(rot_angle+phi);y+r*sin(rot_angle+phi)]' ];
 
  end;
 end;
 %------------------------------------------------------------

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.cleWire),
  ncleWires=length(cleDrawDatOut.cleWire)+1;
  cleDrawDatOut.cleWire{ncleWires}=cleDrawDatIn.cleWire{k};
  cleDrawDatOut.cleWire{ncleWires}.points=[];

  for m=1:length(cleDrawDatIn.cleWire{k}.points),
   r=sqrt( (cleDrawDatIn.cleWire{k}.points(m,1)-x)^2 + (cleDrawDatIn.cleWire{k}.points(m,2)-y)^2);
   phi=angle((cleDrawDatIn.cleWire{k}.points(m,1)-x)+i*(cleDrawDatIn.cleWire{k}.points(m,2)-y));
   
   cleDrawDatOut.cleWire{ncleWires}.points =[cleDrawDatOut.cleWire{ncleWires}.points ; ...
            [ x+r*cos(rot_angle+phi);y+r*sin(rot_angle+phi)]' ];
 
  end;
 end;
 %------------------------------------------------------------
 
 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.cleRing),
  r=sqrt( (cleDrawDatIn.cleRing{k}.x-x)^2 + (cleDrawDatIn.cleRing{k}.y-y)^2);
  phi=angle((cleDrawDatIn.cleRing{k}.x-x)+i*(cleDrawDatIn.cleRing{k}.y-y));
 
  cleDrawDatOut.cleRing{end+1}=cleDrawDatIn.cleRing{k};
  cleDrawDatOut.cleRing{end}.x=x+r*cos(rot_angle+phi);
  cleDrawDatOut.cleRing{end}.y=y+r*sin(rot_angle+phi);
 end;
 %------------------------------------------------------------

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.cleText),
  r=sqrt( (cleDrawDatIn.cleText{k}.x-x)^2 + (cleDrawDatIn.cleText{k}.y-y)^2);
  phi=angle((cleDrawDatIn.cleText{k}.x-x)+i*(cleDrawDatIn.cleText{k}.y-y));
 
  cleDrawDatOut.cleText{end+1}=cleDrawDatIn.cleText{k};
  cleDrawDatOut.cleText{end}.x=x+r*cos(rot_angle+phi);
  cleDrawDatOut.cleText{end}.y=y+r*sin(rot_angle+phi);
  cleDrawDatOut.cleText{end}.angle=cleDrawDatIn.cleText{k}.angle+rot_angle;
 end;
 %------------------------------------------------------------

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.cleSymbol),
  r=sqrt( (cleDrawDatIn.cleSymbol{k}.x-x)^2 + (cleDrawDatIn.cleSymbol{k}.y-y)^2);
  phi=angle((cleDrawDatIn.cleSymbol{k}.x-x)+i*(cleDrawDatIn.cleSymbol{k}.y-y));
 
  cleDrawDatOut.cleSymbol{end+1}=cleDrawDatIn.cleSymbol{k};
  cleDrawDatOut.cleSymbol{end}.x=x+r*cos(rot_angle+phi);
  cleDrawDatOut.cleSymbol{end}.y=y+r*sin(rot_angle+phi);
  cleDrawDatOut.cleSymbol{end}.angle=cleDrawDatIn.cleSymbol{k}.angle+rot_angle;
 end;
 %------------------------------------------------------------

end;


%------------------------------------------------------------
if nargout < 1,
 cleDraw(cleDrawDatOut)
end;


