function [ cleDrawDat ] = cleSymbol(x,y,symbolName,varargin)
%cleSymbol    - Call symbol.
%
%   cleSymbol(x, y, angle, mirror, symbolName, scale)
%       x               - Postion  symbol instance in x direction.
%       y               - Position symbol instance in y direction.
%       symbolName      - Symbol name of symbol to be called.
%       angle           - Optional symbol rotation angle. 
%	mirror          - Optional mirroring, [MirrorX, MirrorY] boolean.
%       scale           - Optional symbol relative scale. (Not supported by CIF format!!).
%
%   cleDraw(cleDrawDat)
%       cleDrawDat     - cleDrawDat data to be writen to CleWin.

if (~isnumeric(x) | ~isnumeric(y) | ~isstr(symbolName) | length(x)~=1 | length(y)~=1 )
    error('CleWin:cleSymbol:InputError', ...
          'Incorrect input parameter(s).');
end;

if nargin>3
 if (length(varargin{1})~=1 | ~isnumeric(varargin{1}))
    error('CleWin:cleSymbol:InputError', ...
          'Incorrect input parameter(s).');
 end;
end;

if nargin>4
 if (length(varargin{2})~=2 | ~islogical(varargin{2}))
    error('CleWin:cleSymbol:InputError', ...
          'Incorrect input parameter(s).');
 end;
end;

if nargin>5
 if (length(varargin{3})~=1 | ~isnumeric(varargin{3}))
    error('CleWin:cleSymbol:InputError', ...
          'Incorrect input parameter(s).');
 end;
end;

%------------------------------------------------------------
cleDrawDat=cleEmpty();
cleDrawDat.cleSymbol{1}.x=x;
cleDrawDat.cleSymbol{1}.y=y;
cleDrawDat.cleSymbol{1}.symbolName=symbolName;

if nargin>3,
 cleDrawDat.cleSymbol{1}.angle=varargin{1};
else
  cleDrawDat.cleSymbol{1}.angle=0;
end;

if nargin>4,
 cleDrawDat.cleSymbol{1}.mirror=varargin{2};
else
  cleDrawDat.cleSymbol{1}.mirror=[false false];
end;

if nargin>5,
 cleDrawDat.cleSymbol{1}.scale=varargin{3};
else
  cleDrawDat.cleSymbol{1}.scale=1;
end;

if nargout < 1,
 cleDraw(cleDrawDat);
end;

%------------------------------------------------------------